import { ConfigProvider, Layout, theme } from "antd";
import DashboardLayout from "./core/components/DashboardLayout";
import {
  darkMode,
  primaryColor,
  setBannerUrl,
  setLogoUrl,
  setPrimaryColor,
  setUserAuthenticated,
  userAuthenticated,
  setUserProfilePictureUrl,
} from "./core/reducers/appSlice";
import { useDispatch, useSelector } from "react-redux";
import SignIn from "./features/Auth/SignIn";
import { useEffect } from "react";
import { myFetch } from "./core/utils/utils";
import MyCenteredSpin from "./shared/components/MyCenteredSpin";
import webSocketService, {
  WebSocketMessageHandler,
} from "core/services/websocketService";
import { MessageProvider } from "core/context/MessageContext";

const { defaultAlgorithm, darkAlgorithm } = theme;

export default function App() {
  const dispatch = useDispatch();

  const isDarkMode = useSelector(darkMode);
  const uAuthenticated = useSelector(userAuthenticated);
  const primColor = useSelector(primaryColor);

  console.info(
    "\n %c LMS %c v1.0.0 %c \n",
    "background-color: #555;color: #fff;padding: 3px 2px 3px 3px;border-radius: 3px 0 0 3px;font-family: DejaVu Sans,Verdana,Geneva,sans-serif;text-shadow: 0 1px 0 rgba(1, 1, 1, 0.3)",
    "background-color: #bc81e0;background-image: linear-gradient(90deg, #e67e22, #9b59b6);color: #fff;padding: 3px 3px 3px 2px;border-radius: 0 3px 3px 0;font-family: DejaVu Sans,Verdana,Geneva,sans-serif;text-shadow: 0 1px 0 rgba(1, 1, 1, 0.3)",
    "background-color: transparent"
  );

  useEffect(() => {
    if (uAuthenticated) {
      (async () => {
        try {
          const response = await myFetch({
            url: "/app",
            method: "GET",
          });

          if (response) {
            dispatch(setPrimaryColor(`#${response.Organization.PrimaryColor}`));
            dispatch(setLogoUrl(response.Organization.LogoUrl));
            dispatch(setBannerUrl(response.Organization.BannerUrl));
            dispatch(setUserProfilePictureUrl(response.User.ProfilePictureUrl));
            dispatch(setUserAuthenticated(true));

            webSocketService.connect();
            webSocketService.setHandler(WebSocketMessageHandler, dispatch);
          }
        } catch (error) {}
      })();

      return () => {
        webSocketService.disconnect();
      };
    }
  }, [uAuthenticated]);

  useEffect(() => {
    const query = new URLSearchParams(window.location.search);

    if (!localStorage.getItem("session") && !query.has("s")) {
      dispatch(setUserAuthenticated(false));
    } else if (query.has("s")) {
      const searchParam = query.get("s");

      if (searchParam) {
        localStorage.setItem("session", searchParam);

        window.history.replaceState(
          {},
          document.title,
          window.location.pathname
        );

        dispatch(setUserAuthenticated(true));
      } else {
        dispatch(setUserAuthenticated(false));
      }
    } else {
      dispatch(setUserAuthenticated(true));
    }
  }, [dispatch]);

  useEffect(() => {
    const plScript = document.createElement("script");
    plScript.src = "https://anal.jannex.de/js/script.js";
    plScript.async = true;
    plScript.defer = true;
    plScript.setAttribute("data-domain", "dashboard.navilearn.io");
    document.head.appendChild(plScript);
  }, []);

  return (
    <Layout style={{ minHeight: "100vh" }}>
      <ConfigProvider
        theme={{
          algorithm: isDarkMode ? darkAlgorithm : defaultAlgorithm,
          token: {
            colorPrimary: primColor,
          },
        }}
      >
        <MessageProvider>
          {uAuthenticated == null ? (
            <MyCenteredSpin />
          ) : uAuthenticated ? (
            <DashboardLayout />
          ) : (
            <SignIn />
          )}
        </MessageProvider>
      </ConfigProvider>
    </Layout>
  );
}
