import { createSlice } from "@reduxjs/toolkit";
import { CachedUser } from "core/types/userProfile";

export const appSlice = createSlice({
  name: "app",
  initialState: {
    darkMode: false,
    userAuthenticated: null,
    userProfilePictureUrl: null,
    primaryColor: "#111",
    logoUrl: null,
    bannerUrl: null,
    cachedUsers: {} as Record<string, CachedUser>,
  },
  reducers: {
    setDarkMode: (state, action) => {
      state.darkMode = action.payload;
    },
    setUserAuthenticated: (state, action) => {
      state.userAuthenticated = action.payload;
    },
    setUserProfilePictureUrl: (state, action) => {
      state.userProfilePictureUrl = action.payload;
    },
    setPrimaryColor: (state, action) => {
      state.primaryColor = action.payload;
    },
    setLogoUrl: (state, action) => {
      state.logoUrl = action.payload;
    },
    setBannerUrl: (state, action) => {
      state.bannerUrl = action.payload;
    },
    addUserToCache: (state, action) => {
      state.cachedUsers[action.payload.id] = action.payload;
    },
  },
  selectors: {
    darkMode: (state) => state.darkMode,
    userAuthenticated: (state) => state.userAuthenticated,
    userProfilePictureUrl: (state) => state.userProfilePictureUrl,
    primaryColor: (state) => state.primaryColor,
    logoUrl: (state) => state.logoUrl,
    bannerUrl: (state) => state.bannerUrl,
    cachedUsers: (state) => state.cachedUsers,
  },
});

export const {
  setDarkMode,
  setUserAuthenticated,
  setUserProfilePictureUrl,
  setPrimaryColor,
  setLogoUrl,
  setBannerUrl,
  addUserToCache,
} = appSlice.actions;

export const {
  darkMode,
  userAuthenticated,
  userProfilePictureUrl,
  primaryColor,
  logoUrl,
  bannerUrl,
  cachedUsers,
} = appSlice.selectors;
