import { createApi } from "@reduxjs/toolkit/query/react";
import { baseQueryWithErrorHandling } from "core/helper/api";
import {
  TeamMember,
  OrganizationSettings,
  Roles,
} from "core/types/organization";

export const organizationApi = createApi({
  reducerPath: "organizationApi",
  baseQuery: baseQueryWithErrorHandling,
  endpoints: (builder) => ({
    getTeam: builder.query<TeamMember[], undefined>({
      query: () => ({
        url: "organization/team/members",
        method: "GET",
      }),
    }),
    createTeamMember: builder.mutation({
      query: ({ firstName, lastName, email, roleId, password }) => ({
        url: "organization/team/members",
        method: "POST",
        body: {
          FirstName: firstName,
          LastName: lastName,
          Email: email,
          RoleId: roleId,
          Password: password,
        },
      }),
    }),
    updateTeamMemberRole: builder.mutation({
      query: ({ memberId, roleId }) => ({
        url: `organization/team/members/${memberId}/role`,
        method: "PATCH",
        body: {
          RoleId: roleId,
        },
      }),
    }),
    deleteTeamMember: builder.mutation({
      query: (memberId) => ({
        url: `organization/team/members/${memberId}`,
        method: "DELETE",
      }),
    }),
    getOrganizationSettings: builder.query<OrganizationSettings, undefined>({
      query: () => ({
        url: "organization/settings",
        method: "GET",
      }),
    }),
    updateOrganizationSettings: builder.mutation({
      query: ({ primaryColor, companyName }) => ({
        url: "organization/settings",
        method: "PATCH",
        body: { PrimaryColor: primaryColor, CompanyName: companyName },
      }),
    }),
    isSubdomainAvailable: builder.mutation({
      query: (subdomain) => ({
        url: `organization/subdomain/${subdomain}`,
        method: "GET",
      }),
    }),
    updateSubdomain: builder.mutation({
      query: (subdomain) => ({
        url: `organization/subdomain/${subdomain}`,
        method: "PATCH",
      }),
    }),
    getRoles: builder.query<Roles, undefined>({
      query: () => ({
        url: "organization/roles",
        method: "GET",
      }),
    }),
  }),
});

export const {
  useGetTeamQuery,
  useCreateTeamMemberMutation,
  useUpdateTeamMemberRoleMutation,
  useDeleteTeamMemberMutation,
  useGetOrganizationSettingsQuery,
  useUpdateOrganizationSettingsMutation,
  useIsSubdomainAvailableMutation,
  useUpdateSubdomainMutation,
  useGetRolesQuery,
} = organizationApi;
