import { configureStore } from "@reduxjs/toolkit";
import { setupListeners } from "@reduxjs/toolkit/query";
import { sideMenuSlice } from "../components/SideMenu/sideMenuSlice";
import { lessonPageEditorSlice } from "../../features/Lessons/LessonPageEditor/lessonPageEditorSlice";
import { appSlice } from "../reducers/appSlice";
import { lessonsApi } from "core/services/lessons";
import { organizationApi } from "core/services/organization";
import { teamSlice } from "features/Team/teamSlice";
import { lessonsSlice } from "features/Lessons/lessonsSlice";
import { lessonPageSlice } from "features/Lessons/LessonPage/lessonPageSlice";
import { userProfileApi } from "core/services/userProfile";
import { userProfileSlice } from "features/UserProfile/userProfileSlice";
import { lessonQuestionsSlice } from "features/Lessons/Questions/lessonQuestionSlice";

const makeStore = (/* preloadedState */) => {
  const store = configureStore({
    reducer: {
      app: appSlice.reducer,
      sideMenu: sideMenuSlice.reducer,
      lessonPageEditor: lessonPageEditorSlice.reducer,
      teamSlice: teamSlice.reducer,
      [lessonsApi.reducerPath]: lessonsApi.reducer,
      [lessonsSlice.reducerPath]: lessonsSlice.reducer,
      [lessonPageSlice.reducerPath]: lessonPageSlice.reducer,
      [lessonQuestionsSlice.reducerPath]: lessonQuestionsSlice.reducer,
      [organizationApi.reducerPath]: organizationApi.reducer,
      [teamSlice.reducerPath]: teamSlice.reducer,
      [userProfileApi.reducerPath]: userProfileApi.reducer,
      [userProfileSlice.reducerPath]: userProfileSlice.reducer,
    },
    // preloadedState,
    middleware: (getDefaultMiddleware) =>
      getDefaultMiddleware().concat(
        lessonsApi.middleware,
        organizationApi.middleware,
        userProfileApi.middleware
      ),
  });

  setupListeners(store.dispatch);
  return store;
};

export const store = makeStore();
