import React from 'react';
import { FloatButton } from 'antd';
import { CommentOutlined } from '@ant-design/icons';
import { DeepChat } from 'deep-chat-react';
import { getUserSessionFromLocalStorage } from 'core/utils/utils';

import { Marked, marked } from 'marked';
import { createDirectives, presetDirectiveConfigs } from 'marked-directive';

interface MessageContent {
    role?: string;
    text?: string;
    files?: any[];
    html?: string;
}

let chatHistory: MessageContent[] = [
    {
        text: 'Hallo! Ich bin ein Chatbot. Stell mir Fragen :)',
        role: 'ai',
    },
];

function AiChat() {
    const [visible, setVisible] = React.useState(false);

    //const [chatHistory, setChatHistory] = React.useState<MessageContent[]>([{ text: 'Stell mir Fragen :)', role: 'ai' }]);

    return (
        <>
            {visible ? (
                <div
                    style={{
                        position: 'fixed',
                        bottom: 100,
                        right: 10,
                        zIndex: 10000,
                        maxWidth: '95vw',
                        width: 500,
                        height: 1000,
                        maxHeight: 'calc(100vh - 165px)',
                    }}
                >
                    <DeepChat
                        style={{
                            width: '100%',
                            height: '100%',
                            borderRadius: 10,
                            boxShadow: '0 0 10px rgba(0,0,0,0.1)',
                            bottom: 0,
                            position: 'absolute',
                        }}
                        avatars={true}
                        history={chatHistory}
                        onMessage={(message) => {
                            if (message.isHistory) return;

                            //setChatHistory([...chatHistory, message.message]);
                            chatHistory.push(message.message);
                        }}
                        connect={{
                            url: '/api/chat/v1/prompt/',
                            method: 'POST',
                            headers: {
                                'X-Authorization': getUserSessionFromLocalStorage() || '',
                            },
                        }}
                        htmlClassUtilities={{
                            ['aiButtonSource']: {
                                styles: {
                                    default: {
                                        backgroundColor: '#1890ff',
                                        color: 'white',
                                        padding: '5px 10px',
                                        borderRadius: '5px',
                                        textDecoration: 'none',
                                        margin: '4px',
                                        display: 'inline-block',
                                        transition: 'all 0.3s ease-in-out',
                                    },
                                    hover: {
                                        backgroundColor: '#40a9ff',
                                        transform: 'scale(1.05)',
                                    },
                                },
                            },
                        }}
                        requestInterceptor={async (requestDetails) => {
                            console.log(requestDetails); // printed above
                            requestDetails.body.isFirstMessage = chatHistory.length <= 1;
                            return requestDetails;
                        }}
                        responseInterceptor={async (response: any) => {
                            let _response = { ...response };

                            let text = response.text;

                            delete _response.text;

                            // Regular expression to match pattern %URL%x%URL%
                            //const re = /%URL%(.*?)%URL%/g;
                            // Replace pattern with an HTML anchor tag
                            //text = text.replace(re, '@@[Mehr Infos]{href="$1"}');

                            _response.html = new Marked()
                                .use(
                                    createDirectives([
                                        ...presetDirectiveConfigs,
                                        {
                                            level: 'block',
                                            marker: 'µ',
                                            renderer(token) {
                                                return `<a class="aiButtonSource" ${token.attrs?.toString()}>${token.text}</a>`;
                                            },
                                        },
                                    ])
                                )
                                .parse(text);

                            return _response;
                        }}
                    ></DeepChat>
                </div>
            ) : null}

            <FloatButton
                icon={<CommentOutlined />}
                type="primary"
                onClick={() => console.log('onClick')}
                style={{ zIndex: 10000 }}
                onClickCapture={() => {
                    setVisible(!visible);
                }}
            />
        </>
    );
}

export default AiChat;
