import { Button, Card, ConfigProvider, Flex, Form, Input } from "antd";
import { useForm } from "antd/es/form/Form";
import styles from "./styles.module.css";
import { Constants, EncodeStringToBase64, myFetch } from "core/utils/utils";
import { useState } from "react";
import { useDispatch } from "react-redux";
import { setUserAuthenticated } from "core/reducers/appSlice";

type FieldType = {
  email: string;
  password: string;
};

interface SignInFetchResponse {
  Session: string;
}

export default function SignIn() {
  const [form] = useForm<FieldType>();

  const dispatch = useDispatch();

  const [isRequesting, setIsRequesting] = useState(false);

  const handleSignIn = async (values: FieldType) => {
    setIsRequesting(true);

    try {
      const response = await myFetch<FieldType, SignInFetchResponse>({
        url: "/user/auth/login",
        method: "POST",
        body: {
          email: values.email,
          password: EncodeStringToBase64(values.password),
        },
        ignoreUnauthorized: true,
      });

      setIsRequesting(false);

      localStorage.setItem("session", response.Session);

      dispatch(setUserAuthenticated(true));
    } catch (error) {
      console.log("here", error);
      setIsRequesting(false);
    }
  };

  return (
    <>
      <div className={styles.backgroundImage} />
      <div className={styles.darkenBackground} />

      <Flex
        justify="center"
        align="center"
        style={{ position: "absolute", height: "100vh", width: "100%" }}
      >
        <Card style={{ width: 450, margin: 20 }}>
          <h1 style={{ marginTop: 0 }}>Sign In</h1>

          <ConfigProvider
            theme={{
              token: {
                colorPrimary: Constants.STYLES.BLACK,
              },
            }}
          >
            <Form
              form={form}
              layout="vertical"
              requiredMark={false}
              onFinish={handleSignIn}
            >
              <Form.Item<FieldType>
                label="Email"
                name="email"
                rules={[
                  {
                    required: true,
                    type: "email",
                    message: "Please input your email!",
                  },
                ]}
              >
                <Input placeholder="Email" />
              </Form.Item>

              <Form.Item<FieldType>
                label="Password"
                name="password"
                rules={[
                  { required: true, message: "Please input your password!" },
                ]}
              >
                <Input.Password placeholder="Password" />
              </Form.Item>

              <Form.Item style={{ marginBottom: 0 }}>
                <Button
                  type="primary"
                  htmlType="submit"
                  block
                  loading={isRequesting}
                >
                  Sign In
                </Button>
              </Form.Item>
            </Form>
          </ConfigProvider>
        </Card>
      </Flex>
    </>
  );
}
