// Desc: This file contains the list of components that are used in the Lessons

type ComponentGroup = {
  category: string;
  components: Component[];
};

export type Component = {
  type: number;
  name: string;
  thumbnail?: string;
  invertThumbnailAtDarkmode?: boolean;
  uploadFileTypes?: string[];
  uploadImage?: boolean;
  defaultData?: string;
};

const componentsGroups: ComponentGroup[] = [
  {
    category: "Common",
    components: [
      {
        type: 0,
        name: "Header",
        thumbnail: "/editor/thumbnails/component_thumbnail_header.svg",
        invertThumbnailAtDarkmode: true,
        defaultData: "Header",
      },
      {
        type: 1,
        name: "Text",
        thumbnail: "/editor/thumbnails/component_thumbnail_text.svg",
        invertThumbnailAtDarkmode: true,
        defaultData: "Text",
      },
    ],
  },
  {
    category: "Media",
    components: [
      {
        type: 2,
        name: "Image",
        thumbnail: "/editor/thumbnails/component_thumbnail_image.png",
        uploadImage: true,
        uploadFileTypes: ["image/*"],
      },
      {
        type: 3,
        name: "YouTube",
        thumbnail: "/editor/thumbnails/component_thumbnail_youtube.png",
        invertThumbnailAtDarkmode: true,
      },
      {
        type: 4,
        name: "Video",
        thumbnail: "/editor/thumbnails/component_thumbnail_youtube.png",
        invertThumbnailAtDarkmode: true,
      },
    ],
  },
  /*
  {
    category: "HTML",
    components: [
      {
        type: 5,
        name: "Iframe",
        thumbnail: "/editor/thumbnails/component_thumbnail_iframe.svg",
        invertThumbnailAtDarkmode: true,
      },
    ],
  },
  {
    category: "Special",
    components: [
      {
        type: 6,
        name: "Banner",
        thumbnail: "/editor/thumbnails/component_thumbnail_banner.png",
      },
    ],
  }, */
];

const componentsMap: { [key: string]: Component } = (() => {
  const map: { [key: string]: Component } = {};

  for (const group of componentsGroups) {
    for (const component of group.components) {
      map[component.name] = component;
    }
  }
  return map;
})();

export function getTypeByName(name: string): number {
  const component = componentsMap[name];

  return component ? component.type : -1;
}

export function getComponentByType(type: number): Component | null {
  for (const component of Object.values(componentsMap)) {
    if (component.type === type) {
      return component;
    }
  }

  return null;
}

export { componentsGroups };
