import { createSlice } from "@reduxjs/toolkit";
import { Lesson } from "core/types/lesson";

interface AddLessonAction {
  type: string;
  payload: Lesson;
}

export const lessonsSlice = createSlice({
  name: "lessons",
  initialState: {
    lessons: [] as Lesson[],
    searchFilter: "",
  },
  reducers: {
    setLessons: (state, action) => {
      state.lessons = action.payload;
    },
    addLesson: (state, action: AddLessonAction) => {
      state.lessons.push(action.payload);
    },
    updateLessonPreviewTitle: (state, action) => {
      const lesson = state.lessons.find(
        (lesson) => lesson.Id === action.payload.LessonId
      );

      if (lesson) {
        lesson.Title = action.payload.Title;
      }
    },
    updateLessonPreviewThumbnail: (state, action) => {
      const lesson = state.lessons.find(
        (lesson) => lesson.Id === action.payload.LessonId
      );

      if (lesson) {
        lesson.ThumbnailUrl = action.payload.ThumbnailUrl;
      }
    },
    updateLessonState: (state, action) => {
      const lesson = state.lessons.find(
        (lesson) => lesson.Id === action.payload.LessonId
      );

      if (lesson) {
        lesson.State = action.payload.State;
      }
    },
    setSearchFilter: (state, action) => {
      state.searchFilter = action.payload;
    },
  },
  selectors: {
    lessons: (state) => state.lessons,
    searchFilter: (state) => state.searchFilter,
  },
});

export const {
  setLessons,
  addLesson,
  updateLessonPreviewTitle,
  updateLessonPreviewThumbnail,
  updateLessonState,
  setSearchFilter,
} = lessonsSlice.actions;

export const { lessons, searchFilter } = lessonsSlice.selectors;
