import { Avatar } from "antd";
import { Constants } from "core/utils/utils";
import { UserOutlined } from "@ant-design/icons";
import { primaryColor } from "core/reducers/appSlice";
import { useSelector } from "react-redux";

interface MyUserAvatarProps {
  size?: number;
  firstName?: string;
  profilePictureUrl: string;
  disableCursorPointer?: boolean;
}

const MyUserAvatar: React.FC<MyUserAvatarProps> = ({
  size = 56,
  firstName,
  profilePictureUrl,
  disableCursorPointer,
}) => {
  const appPrimaryColor = useSelector(primaryColor);

  const defaultStyle =
    disableCursorPointer === undefined ? { cursor: "pointer" } : {};

  const isProfilePictureEmpty = profilePictureUrl === "";
  const avatarContent =
    isProfilePictureEmpty && firstName !== undefined ? (
      <span style={{ fontSize: 16 }}>{firstName.charAt(0)}</span>
    ) : undefined;
  const iconContent =
    isProfilePictureEmpty && firstName === undefined ? (
      <UserOutlined />
    ) : undefined;
  const avatarSrc = isProfilePictureEmpty
    ? undefined
    : `${Constants.STATIC_CONTENT_ADDRESS}/${profilePictureUrl}`;
  const avatarStyle = isProfilePictureEmpty
    ? { ...defaultStyle, backgroundColor: `#${appPrimaryColor}` }
    : defaultStyle;

  return (
    <div style={{ userSelect: "none" }}>
      <Avatar
        size={size}
        style={avatarStyle}
        src={avatarSrc}
        icon={iconContent}
      >
        {avatarContent}
      </Avatar>
    </div>
  );
};

export default MyUserAvatar;
